@@ -8,5 +8,7 @@ from .focal_loss import (
 from .giou_loss import giou_loss
 from .smooth_l1_loss import smooth_l1_loss
 from .iou_guided_loss import iou_guided_loss
+from .dice_loss import dice_loss
+from .label_smooth_ce_loss import LabelSmoothCELoss, label_smooth_ce_loss
 
 __all__ = [k for k in globals().keys() if not k.startswith("_")]
