@@ -1,10 +1,10 @@
 # Copyright (c) Gorilla-Lab. All rights reserved.
 from .weight_init import (bias_init_with_prob, constant_init, kaiming_init,
                           normal_init, uniform_init, xavier_init, c2_msra_init,
-                          c2_xavier_init)
+                          c2_xavier_init, geometric_init)
 
 from .conv import GorillaConv
-from .FC import GorillaFC, MultiFC
+from .FC import GorillaFC, MultiFC, DenseFC
 from .vgg import VGG
 from .alexnet import AlexNet
 from .resnet import (BasicBlock, Bottleneck, ResNet, conv3x3, resnet18,
