@@ -1,6 +1,6 @@
 # Copyright (c) Gorilla-Lab. All rights reserved.
 
-from .base import (type_assert, convert_into_torch_tensor, convert_into_nparray, assert_and_auto_type)
+from .typing import (type_assert, convert_into_torch_tensor, convert_into_nparray, assert_and_auto_type, to_float32)
 
 from .gpu import (get_free_gpu, set_cuda_visible_devices)
 
